waveformtools.diagnostics — waveformtools 2022-05-03 documentation

# waveformtools.diagnostics

Diagnostic tools

Functions

`IsModesEqual`(modes1, modes2, modes_list) | Check if the mode amplitudes are equal
`RMSerrs`(func1, func2, info) | Compute and return the RMS error between two arrays

Classes

`method_info`([int_method, diff_method, ...]) | The methods for integration ,differential to be passed on for operations.

waveformtools.diagnostics.IsModesEqual(modes1, modes2, modes_list)

  Check if the mode amplitudes are equal

  Parameters:
    modes1, modes2dict

      A dictionary of modes. For each mode, the data could be an array.

    modes_listlist

      A list of list of mode numbers

    Returns
    ——-
    modes_errfloat

      The error of each mode as a dict

waveformtools.diagnostics.RMSerrs(func1, func2, info)

  Compute and return the RMS error between two arrays

  Parameters:
    func1, func2ndarray

      Arrays of same shape to compare with.

    infosphericalarray

      Grid info

  Returns:
    RMSfloat

      The RMS error

    Amaxfloat

      The max diff

    Aminfloat the min diff

class waveformtools.diagnostics.method_info(int_method='MP', diff_method='SH', ell_max=8, degree=8, reg=True)

  The methods for integration ,differential to be passed on for operations.